@@ -131,11 +131,9 @@ private Q_SLOTS:
     void slotSaveComicAs();
     void slotScaleToContent();
     void slotShop();
+    void slotWebsite();
     void slotStorePosition();
     void checkDayChanged();
-    void createComicBook();
-    void slotArchive(int archiveType, const QUrl &dest, const QString &fromIdentifier, const QString &toIdentifier);
-    void slotArchiveFinished(KJob *job);
 
 public Q_SLOTS:
     void configChanged() override;
@@ -205,6 +203,7 @@ private:
     QAction *mActionGoLast;
     QAction *mActionGoJump;
     QAction *mActionScaleContent;
+    QAction *mActionWebsite;
     QAction *mActionShop;
     QAction *mActionStorePosition;
     QAction *mActionNextNewStripTab;
