@@ -23,7 +23,7 @@ public:
     explicit QtCalendarProvider(QObject *parent, CalendarSystem::System calendarSystem);
     ~QtCalendarProvider() override;
 
-    QDate fromGregorian(const QDate &date) const override;
+    QCalendar::YearMonthDay fromGregorian(const QDate &date) const override;
     CalendarEvents::CalendarEventsPlugin::SubLabel subLabels(const QDate &date) const override;
 
 private:
